KLineChartStyle class

Visual styling for the main chart canvas and auxiliary chart labels.

Constructors

KLineChartStyle({Color backgroundColor = Colors.transparent, Color gridLineColor = const Color(0x33607d8b), double gridLineWidth = 0.0, TextStyle rulerTextStyle = const TextStyle(color: Color(0xff999999), fontSize: 12.0, height: 1.0), Color highLowLineColor = const Color(0xff999999), double highLowLineWidth = 1.0, TextStyle highLowTextStyle = const TextStyle(color: Color(0xff666666), fontSize: 13.0, height: 1.0), Color currentPriceLineColor = Colors.black54, double currentPriceLineWidth = 1.0, Color currentPriceBackgroundColor = Colors.white, TextStyle currentPriceTextStyle = const TextStyle(color: Color(0xff999999), fontSize: 12.0, height: 1.0), Color timeLineColor = Colors.blue, double timeLineWidth = 1.0, Color timeLineFillColor = const Color(0xff40c4ff)})
Creates main chart visual styling.
const

Properties

backgroundColor Color
Background color painted behind the entire chart.
final
currentPriceBackgroundColor Color
Background color for the current price marker.
final
currentPriceLineColor Color
Line and border color for the current price marker.
final
currentPriceLineWidth double
Stroke width for the current price line and marker border.
final
currentPriceTextStyle TextStyle
Text style for the current price marker.
final
gridLineColor Color
Grid line color for vertical and horizontal ruler lines.
final
gridLineWidth double
Grid line stroke width.
final
hashCode int
The hash code for this object.
no setteroverride
highLowLineColor Color
Line color for highest and lowest price callouts.
final
highLowLineWidth double
Line stroke width for highest and lowest price callouts.
final
highLowTextStyle TextStyle
Text style for highest and lowest price labels.
final
rulerTextStyle TextStyle
Text style for price ruler labels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeLineColor Color
Line color for time chart mode.
final
timeLineFillColor Color
Fill color for the time chart area gradient.
final
timeLineWidth double
Stroke width for time chart mode.
final

Methods

copyWith({Color? backgroundColor, Color? gridLineColor, double? gridLineWidth, TextStyle? rulerTextStyle, Color? highLowLineColor, double? highLowLineWidth, TextStyle? highLowTextStyle, Color? currentPriceLineColor, double? currentPriceLineWidth, Color? currentPriceBackgroundColor, TextStyle? currentPriceTextStyle, Color? timeLineColor, double? timeLineWidth, Color? timeLineFillColor}) KLineChartStyle
Returns a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override