maxTrailingBlankItemCount property
Maximum empty candle slots that can be revealed after the latest data item.
Implementation
double maxTrailingBlankItemCount = 20;
Maximum empty candle slots that can be revealed after the latest data item.
double maxTrailingBlankItemCount = 20;