trailingBlankItemCount property
Empty candle slots shown after the latest data item when aligned to the end.
Implementation
double trailingBlankItemCount = 5;
Empty candle slots shown after the latest data item when aligned to the end.
double trailingBlankItemCount = 5;