KLineData class

Constructors

KLineData({double open = 0.0, double high = 0.0, double low = 0.0, double close = 0.0, double volume = 0.0, int time = 0})
KLineData.fromJson(dynamic json)

Properties

close double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
high double
getter/setter pair
low double
getter/setter pair
open double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int
getter/setter pair
volume double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited