KLineDataChange class

Constructors

KLineDataChange({required KLineDataChangeType type, required int previousLength, required int newLength, int addedCount = 0, bool resetView = false})
const

Properties

addedCount int
final
hashCode int
The hash code for this object.
no setterinherited
newLength int
final
previousLength int
final
resetView bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type KLineDataChangeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited