KLineOverlayStyle class

Visual styling for display-only chart overlays.

Constructors

KLineOverlayStyle({Color priceLineColor = Colors.blue, double priceLineStrokeWidth = 1.0, TextStyle priceLineTextStyle = const TextStyle(color: Colors.white, fontSize: 10.0, height: 1.0), Color priceLineLabelBackgroundColor = Colors.blue, EdgeInsets priceLineLabelPadding = const EdgeInsets.symmetric(horizontal: 4, vertical: 2), double priceLineLabelBorderRadius = 3.0, Color zoneColor = Colors.blue, double zoneOpacity = 0.12, TextStyle zoneTextStyle = const TextStyle(color: Colors.blue, fontSize: 10.0, height: 1.0), Color buyMarkerColor = Colors.green, Color sellMarkerColor = Colors.red, Color customMarkerColor = Colors.blue, Color markerTextColor = Colors.white, double markerRadius = 6.0, TextStyle markerTextStyle = const TextStyle(color: Colors.white, fontSize: 10.0, height: 1.0, fontWeight: FontWeight.w600), Color verticalLineColor = Colors.blueGrey, double verticalLineStrokeWidth = 1.0, TextStyle verticalLineTextStyle = const TextStyle(color: Colors.blueGrey, fontSize: 10.0, height: 1.0)})
Creates display-only overlay visual styling.
const

Properties

buyMarkerColor Color
Default color for buy markers.
final
customMarkerColor Color
Default color for custom markers.
final
hashCode int
The hash code for this object.
no setteroverride
markerRadius double
Default marker radius.
final
markerTextColor Color
Text color used inside markers.
final
markerTextStyle TextStyle
Text style for marker labels.
final
priceLineColor Color
Default color for horizontal price lines.
final
priceLineLabelBackgroundColor Color
Background color for price line labels.
final
priceLineLabelBorderRadius double
Border radius for price line labels.
final
priceLineLabelPadding EdgeInsets
Padding around price line label text.
final
priceLineStrokeWidth double
Default stroke width for horizontal price lines.
final
priceLineTextStyle TextStyle
Text style for price line labels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellMarkerColor Color
Default color for sell markers.
final
verticalLineColor Color
Default color for vertical event lines.
final
verticalLineStrokeWidth double
Default stroke width for vertical event lines.
final
verticalLineTextStyle TextStyle
Text style for vertical event line labels.
final
zoneColor Color
Default fill color for price zones.
final
zoneOpacity double
Default opacity for price zone fills.
final
zoneTextStyle TextStyle
Text style for price zone labels.
final

Methods

copyWith({Color? priceLineColor, double? priceLineStrokeWidth, TextStyle? priceLineTextStyle, Color? priceLineLabelBackgroundColor, EdgeInsets? priceLineLabelPadding, double? priceLineLabelBorderRadius, Color? zoneColor, double? zoneOpacity, TextStyle? zoneTextStyle, Color? buyMarkerColor, Color? sellMarkerColor, Color? customMarkerColor, Color? markerTextColor, double? markerRadius, TextStyle? markerTextStyle, Color? verticalLineColor, double? verticalLineStrokeWidth, TextStyle? verticalLineTextStyle}) KLineOverlayStyle
Returns a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override