KLineTimeLabelGranularity enum

Time label granularity selected from the currently visible time span.

Inheritance
Available extensions

Values

time → const KLineTimeLabelGranularity

Intraday labels, formatted as HH:mm by default.

day → const KLineTimeLabelGranularity

Day labels, formatted as MM-dd by default.

month → const KLineTimeLabelGranularity

Month labels, formatted as yyyy-MM by default.

year → const KLineTimeLabelGranularity

Year labels, formatted as yyyy by default.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KLineTimeLabelGranularity>
A constant List of the values in this enum, in order of their declaration.