KLineCandleStyle class

Visual styling for candlestick bodies and wicks.

Constructors

KLineCandleStyle({Color riseColor = Colors.green, Color fallColor = Colors.red, Color riseWickColor = Colors.green, Color fallWickColor = Colors.red, double wickLineWidth = 2.0})
Creates candlestick visual styling.
const

Properties

fallColor Color
Candle body color when close is less than or equal to open.
final
fallWickColor Color
Candle wick color when close is less than or equal to open.
final
hashCode int
The hash code for this object.
no setteroverride
riseColor Color
Candle body color when close is greater than open.
final
riseWickColor Color
Candle wick color when close is greater than open.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wickLineWidth double
Candle wick stroke width.
final

Methods

copyWith({Color? riseColor, Color? fallColor, Color? riseWickColor, Color? fallWickColor, double? wickLineWidth}) KLineCandleStyle
Returns a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override