KLineCrosshairStyle class
Visual styling for the long-press crosshair.
Constructors
- KLineCrosshairStyle({Color color = const Color(0xcc607d8b), double strokeWidth = 0.0})
-
Creates long-press crosshair visual styling.
const
Properties
- color → Color
-
Crosshair line color.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
Crosshair line stroke width.
final
Methods
-
copyWith(
{Color? color, double? strokeWidth}) → KLineCrosshairStyle - Returns a copy with selected values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override