KLinePriceZone class
Filled price range annotation between two price values.
- Inheritance
-
- Object
- KLineOverlay
- KLinePriceZone
Constructors
Properties
- color → Color?
-
Optional fill and label color override.
final
- fromPrice → double
-
First price boundary.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
Optional text shown inside the zone.
final
- opacity → double?
-
Optional fill opacity override.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toPrice → double
-
Second price boundary.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override