KLineVerticalLine class
Vertical event line annotation anchored to a candle time.
- Inheritance
-
- Object
- KLineOverlay
- KLineVerticalLine
Constructors
- KLineVerticalLine({required int time, String? label, Color? color, double? strokeWidth})
-
Creates a vertical event line annotation.
const
Properties
- color → Color?
-
Optional line and label color override.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String?
-
Optional text shown near the top of the line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double?
-
Optional stroke width override.
final
- time → int
-
Candle timestamp used to align the line to a data item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override