KLineVolumeStyle class

Visual styling for volume bars.

Constructors

KLineVolumeStyle({Color riseColor = Colors.green, Color fallColor = Colors.red})
Creates volume bar visual styling.
const

Properties

fallColor Color
Volume bar color when close is less than or equal to open.
final
hashCode int
The hash code for this object.
no setteroverride
riseColor Color
Volume bar color when close is greater than open.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? riseColor, Color? fallColor}) KLineVolumeStyle
Returns a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override